==> d1-pac-0.0.20.crate: d1-pac-0.0.20/src/gpadc/gp_cdata.rs <==
#[doc = "Register `GP_CDATA` reader"]
pub struct R(crate::R<GP_CDATA_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<GP_CDATA_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<GP_CDATA_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<GP_CDATA_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `GP_CDATA` writer"]
pub struct W(crate::W<GP_CDATA_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<GP_CDATA_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<GP_CDATA_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<GP_CDATA_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `GP_CDATA` reader - GPADC Calibration Data"]
pub struct GP_CDATA_R(crate::FieldReader<u16>);
impl GP_CDATA_R {
    #[inline(always)]
    pub(crate) fn new(bits: u16) -> Self {
        GP_CDATA_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for GP_CDATA_R {
    type Target = crate::FieldReader<u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `GP_CDATA` writer - GPADC Calibration Data"]
pub struct GP_CDATA_W<'a> {
    w: &'a mut W,
}
impl<'a> GP_CDATA_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x0fff) | (value as u32 & 0x0fff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:11 - GPADC Calibration Data"]
    #[inline(always)]
    pub fn gp_cdata(&self) -> GP_CDATA_R {
        GP_CDATA_R::new((self.bits & 0x0fff) as u16)
    }
}
impl W {
    #[doc = "Bits 0:11 - GPADC Calibration Data"]
    #[inline(always)]
    pub fn gp_cdata(&mut self) -> GP_CDATA_W {
        GP_CDATA_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "GPADC Calibration Data Register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gp_cdata](index.html) module"]
pub struct GP_CDATA_SPEC;
impl crate::RegisterSpec for GP_CDATA_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [gp_cdata::R](R) reader structure"]
impl crate::Readable for GP_CDATA_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [gp_cdata::W](W) writer structure"]
impl crate::Writable for GP_CDATA_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets GP_CDATA to value 0"]
impl crate::Resettable for GP_CDATA_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> d1-pac-0.0.22.crate: d1-pac-0.0.22/src/gpadc/gp_cdata.rs <==
#[doc = "Register `GP_CDATA` reader"]
pub struct R(crate::R<GP_CDATA_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<GP_CDATA_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<GP_CDATA_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<GP_CDATA_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `GP_CDATA` writer"]
pub struct W(crate::W<GP_CDATA_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<GP_CDATA_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<GP_CDATA_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<GP_CDATA_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `GP_CDATA` reader - GPADC Calibration Data"]
pub type GP_CDATA_R = crate::FieldReader<u16, u16>;
#[doc = "Field `GP_CDATA` writer - GPADC Calibration Data"]
pub type GP_CDATA_W<'a> = crate::FieldWriter<'a, u32, GP_CDATA_SPEC, u16, u16, 12, 0>;
impl R {
    #[doc = "Bits 0:11 - GPADC Calibration Data"]
    #[inline(always)]
    pub fn gp_cdata(&self) -> GP_CDATA_R {
        GP_CDATA_R::new((self.bits & 0x0fff) as u16)
    }
}
impl W {
    #[doc = "Bits 0:11 - GPADC Calibration Data"]
    #[inline(always)]
    pub fn gp_cdata(&mut self) -> GP_CDATA_W {
        GP_CDATA_W::new(self)
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "GPADC Calibration Data Register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [gp_cdata](index.html) module"]
pub struct GP_CDATA_SPEC;
impl crate::RegisterSpec for GP_CDATA_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [gp_cdata::R](R) reader structure"]
impl crate::Readable for GP_CDATA_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [gp_cdata::W](W) writer structure"]
impl crate::Writable for GP_CDATA_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets GP_CDATA to value 0"]
impl crate::Resettable for GP_CDATA_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
